summaryrefslogtreecommitdiff
path: root/apt-pkg/edsp.cc
diff options
context:
space:
mode:
authorDavid Kalnischkies <david@kalnischkies.de>2016-06-29 09:16:53 +0200
committerDavid Kalnischkies <david@kalnischkies.de>2016-06-29 12:17:41 +0200
commit8e99b22c31eb47d0422e9a69e83dc99bb315ded8 (patch)
tree5b9ce48557151aecda3b34a755c71b1201c48133 /apt-pkg/edsp.cc
parent33aa2752e7c7a6f0a01b191111aa35a5fe69cf20 (diff)
eipp: let apt make a plan, not make stuff plane
Julian noticed on IRC that I fall victim to a lovely false friend by calling referring to a 'planer' all the time even through these are machines to e.g. remove splinters from woodwork ("make stuff plane"). The term I meant is written in german in this way (= with a single n) but in english there are two, aka: 'planner'. As that is unreleased code switching all instances without any transitional provisions. Also the reason why its skipped in changelog. Thanks: Julian Andres Klode Gbp-Dch: Ignore
Diffstat (limited to 'apt-pkg/edsp.cc')
-rw-r--r--apt-pkg/edsp.cc28
1 files changed, 14 insertions, 14 deletions
diff --git a/apt-pkg/edsp.cc b/apt-pkg/edsp.cc
index 49873f243..55bc0fcbd 100644
--- a/apt-pkg/edsp.cc
+++ b/apt-pkg/edsp.cc
@@ -1076,7 +1076,7 @@ bool EIPP::OrderInstall(char const * const solver, pkgPackageManager * const PM,
{
if (strcmp(solver, "internal") == 0)
{
- auto const dumpfile = _config->FindFile("Dir::Log::Planer");
+ auto const dumpfile = _config->FindFile("Dir::Log::Planner");
if (dumpfile.empty())
return false;
auto const dumpdir = flNotFile(dumpfile);
@@ -1089,27 +1089,27 @@ bool EIPP::OrderInstall(char const * const solver, pkgPackageManager * const PM,
}
int solver_in, solver_out;
- pid_t const solver_pid = ExecuteExternal("planer", solver, "Dir::Bin::Planers", &solver_in, &solver_out);
+ pid_t const solver_pid = ExecuteExternal("planner", solver, "Dir::Bin::Planners", &solver_in, &solver_out);
if (solver_pid == 0)
return false;
FileFd output;
if (output.OpenDescriptor(solver_in, FileFd::WriteOnly | FileFd::BufferedWrite, true) == false)
- return _error->Errno("EIPP::OrderInstall", "Opening planer %s stdin on fd %d for writing failed", solver, solver_in);
+ return _error->Errno("EIPP::OrderInstall", "Opening planner %s stdin on fd %d for writing failed", solver, solver_in);
bool Okay = output.Failed() == false;
if (Progress != NULL)
- Progress->OverallProgress(0, 100, 5, _("Execute external planer"));
+ Progress->OverallProgress(0, 100, 5, _("Execute external planner"));
Okay &= EIPP::WriteRequest(PM->Cache, output, flags, Progress);
if (Progress != NULL)
- Progress->OverallProgress(5, 100, 20, _("Execute external planer"));
+ Progress->OverallProgress(5, 100, 20, _("Execute external planner"));
Okay &= EIPP::WriteScenario(PM->Cache, output, Progress);
output.Close();
if (Progress != NULL)
- Progress->OverallProgress(25, 100, 75, _("Execute external planer"));
+ Progress->OverallProgress(25, 100, 75, _("Execute external planner"));
- // we don't tell the external planers about boring things
+ // we don't tell the external planners about boring things
for (auto Pkg = PM->Cache.PkgBegin(); Pkg.end() == false; ++Pkg)
{
if (Pkg->CurrentState == pkgCache::State::ConfigFiles && PM->Cache[Pkg].Purge() == true)
@@ -1127,7 +1127,7 @@ bool EIPP::WriteRequest(pkgDepCache &Cache, FileFd &output, /*{{{*/
OpProgress * const Progress)
{
if (Progress != NULL)
- Progress->SubProgress(Cache.Head().PackageCount, _("Send request to planer"));
+ Progress->SubProgress(Cache.Head().PackageCount, _("Send request to planner"));
unsigned long p = 0;
string del, inst, reinst;
for (pkgCache::PkgIterator Pkg = Cache.PkgBegin(); Pkg.end() == false; ++Pkg, ++p)
@@ -1164,7 +1164,7 @@ bool EIPP::WriteRequest(pkgDepCache &Cache, FileFd &output, /*{{{*/
WriteOkay(Okay, output, "Install:", inst, "\n");
if (reinst.empty() == false)
WriteOkay(Okay, output, "ReInstall:", reinst, "\n");
- WriteOkay(Okay, output, "Planer: ", _config->Find("APT::Planer", "internal"), "\n");
+ WriteOkay(Okay, output, "Planner: ", _config->Find("APT::Planner", "internal"), "\n");
if ((flags & Request::IMMEDIATE_CONFIGURATION_ALL) != 0)
WriteOkay(Okay, output, "Immediate-Configuration: yes\n");
else if ((flags & Request::NO_IMMEDIATE_CONFIGURATION) != 0)
@@ -1217,7 +1217,7 @@ template<typename forVersion> void forAllInterestingVersions(pkgDepCache &Cache,
bool EIPP::WriteScenario(pkgDepCache &Cache, FileFd &output, OpProgress * const Progress)
{
if (Progress != NULL)
- Progress->SubProgress(Cache.Head().PackageCount, _("Send scenario to planer"));
+ Progress->SubProgress(Cache.Head().PackageCount, _("Send scenario to planner"));
unsigned long p = 0;
bool Okay = output.Failed() == false;
std::vector<std::string> archs = APT::Configuration::getArchitectures();
@@ -1318,13 +1318,13 @@ bool EIPP::ReadResponse(int const input, pkgPackageManager * const PM, OpProgres
} else if (section.Exists("Error") == true) {
std::string msg = SubstVar(SubstVar(section.FindS("Message"), "\n .\n", "\n\n"), "\n ", "\n");
if (msg.empty() == true) {
- msg = _("External planer failed without a proper error message");
+ msg = _("External planner failed without a proper error message");
_error->Error("%s", msg.c_str());
} else
- _error->Error("External planer failed with: %s", msg.substr(0,msg.find('\n')).c_str());
+ _error->Error("External planner failed with: %s", msg.substr(0,msg.find('\n')).c_str());
if (Progress != NULL)
Progress->Done();
- std::cerr << "The planer encountered an error of type: " << section.FindS("Error") << std::endl;
+ std::cerr << "The planner encountered an error of type: " << section.FindS("Error") << std::endl;
std::cerr << "The following information might help you to understand what is wrong:" << std::endl;
std::cerr << msg << std::endl << std::endl;
return false;
@@ -1396,7 +1396,7 @@ bool EIPP::ReadRequest(int const input, std::list<std::pair<std::string,PKG_ACTI
_config->Set("APT::Architecture", line);
else if (LineStartsWithAndStrip(line, "Architectures:"))
_config->Set("APT::Architectures", SubstVar(line, " ", ","));
- else if (LineStartsWithAndStrip(line, "Planer:"))
+ else if (LineStartsWithAndStrip(line, "Planner:"))
; // purely informational line
else if (LineStartsWithAndStrip(line, "Immediate-Configuration:"))
{